@@ -25,11 +25,11 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include "glib-utils.h"
 #include "file-utils.h"
 #include "gtk-utils.h"
-#include "window.h"
+#include "fr-window.h"
 
 #define PROP_GLADE_FILE "file-roller.glade"
 
@@ -43,10 +43,10 @@ typedef struct {
 /* called when the main dialog is closed. */
 static void
 destroy_cb (GtkWidget  *widget,
-            DialogData *data)
+	    DialogData *data)
 {
 	g_object_unref (G_OBJECT (data->gui));
-        g_free (data);
+	g_free (data);
 }
 
 
@@ -78,45 +78,42 @@ help_cb (GtkWidget   *w,
 
 
 void
-dlg_prop (FRWindow *window)
+dlg_prop (FrWindow *window)
 {
-        DialogData       *data;
+	DialogData       *data;
 	GtkWidget        *ok_button;
 	GtkWidget        *help_button;
 	GtkWidget        *label_label;
 	GtkWidget        *label;
 	char             *s;
 	GnomeVFSFileSize  size, uncompressed_size;
-	struct tm        *tm;
-	time_t            timer;
-	char              time_txt[50];
 	char             *utf8_name;
 	char             *title_txt;
 	double            ratio;
-	
-        data = g_new (DialogData, 1);
+
+	data = g_new (DialogData, 1);
 
 	data->gui = glade_xml_new (GLADEDIR "/" PROP_GLADE_FILE , NULL, NULL);
 	if (!data->gui) {
-                g_warning ("Could not find " PROP_GLADE_FILE "\n");
-                return;
-        }
+		g_warning ("Could not find " PROP_GLADE_FILE "\n");
+		return;
+	}
 
-        /* Get the widgets. */
+	/* Get the widgets. */
 
-        data->dialog = glade_xml_get_widget (data->gui, "prop_dialog");
+	data->dialog = glade_xml_get_widget (data->gui, "prop_dialog");
 	ok_button = glade_xml_get_widget (data->gui, "p_ok_button");
 	help_button = glade_xml_get_widget (data->gui, "p_help_button");
 
 	/* Set widgets data. */
-	
+
 	label_label = glade_xml_get_widget (data->gui, "p_path_label_label");
 	set_label (label_label, _("Path:"));
 
 	label = glade_xml_get_widget (data->gui, "p_path_label");
 	/* note: window->archive_filename is unescaped. */
-	s = remove_level_from_path (window->archive_filename); 
-	utf8_name = g_filename_display_name (s);
+	s = remove_level_from_path (fr_window_get_archive_uri (window));
+	utf8_name = gnome_vfs_format_uri_for_display (s);
 	gtk_label_set_text (GTK_LABEL (label), utf8_name);
 	g_free (utf8_name);
 	g_free (s);
@@ -127,7 +124,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Name:"));
 
 	label = glade_xml_get_widget (data->gui, "p_name_label");
-	utf8_name = g_filename_display_basename (window->archive_filename);
+	utf8_name = gnome_vfs_unescape_string_for_display (file_name_from_path (fr_window_get_archive_uri (window)));
 	gtk_label_set_text (GTK_LABEL (label), utf8_name);
 
 	title_txt = g_strdup_printf (_("%s Properties"), utf8_name);
@@ -142,11 +139,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Modified on:"));
 
 	label = glade_xml_get_widget (data->gui, "p_date_label");
-
-	timer = get_file_mtime (window->archive->filename);
-	tm = localtime (&timer);
-	strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
-	s = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
+	s = get_time_string (get_file_mtime (fr_window_get_archive_uri (window)));
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
@@ -156,7 +149,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Archive size:"));
 
 	label = glade_xml_get_widget (data->gui, "p_size_label");
-	size = get_file_size (window->archive_filename);
+	size = get_file_size (fr_window_get_archive_uri (window));
 	s = gnome_vfs_format_file_size_for_display (size);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
@@ -167,7 +160,7 @@ dlg_prop (FRWindow *window)
 	set_label (label_label, _("Content size:"));
 
 	uncompressed_size = 0;
-	if (window->archive_present) {
+	if (fr_window_archive_is_present (window)) {
 		GList *scan = window->archive->command->file_list;
 		for (; scan; scan = scan->next) {
 			FileData *fd = scan->data;
@@ -187,7 +180,7 @@ dlg_prop (FRWindow *window)
 
 	label = glade_xml_get_widget (data->gui, "p_cratio_label");
 
-	if (uncompressed_size != 0) 
+	if (uncompressed_size != 0)
 		ratio = (double) uncompressed_size / size;
 	else
 		ratio = 0.0;
@@ -207,24 +200,24 @@ dlg_prop (FRWindow *window)
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (data->dialog), 
+	g_signal_connect (G_OBJECT (data->dialog),
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect_swapped (G_OBJECT (ok_button), 
+	g_signal_connect_swapped (G_OBJECT (ok_button),
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (data->dialog));
-	g_signal_connect (G_OBJECT (help_button), 
+	g_signal_connect (G_OBJECT (help_button),
 			  "clicked",
 			  G_CALLBACK (help_cb),
-			  G_OBJECT (data));
+			  data);
 
 	/* Run dialog. */
 
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
-				      GTK_WINDOW (window->app));
-        gtk_window_set_modal         (GTK_WINDOW (data->dialog), TRUE);
+	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
+				      GTK_WINDOW (window));
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 
 	gtk_widget_show (data->dialog);
 }
