@@ -28,8 +28,6 @@
 #include <fcntl.h>
 
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "file-data.h"
 #include "file-utils.h"
@@ -37,20 +35,20 @@
 #include "fr-command.h"
 #include "fr-command-cfile.h"
 
-static void fr_command_cfile_class_init  (FRCommandCFileClass *class);
-static void fr_command_cfile_init        (FRCommand           *afile);
+static void fr_command_cfile_class_init  (FrCommandCFileClass *class);
+static void fr_command_cfile_init        (FrCommand           *afile);
 static void fr_command_cfile_finalize    (GObject             *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 static char *
-get_uncompressed_name_from_archive (FRCommand  *comm, 
+get_uncompressed_name_from_archive (FrCommand  *comm, 
 				    const char *e_filename)
 {
-	FRCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
+	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 	int             fd;
 	char            buffer[11];
 	char           *filename = NULL;
@@ -108,7 +106,7 @@ static void
 list__process_line (char     *line, 
 		    gpointer  data)
 {
-	FRCommand  *comm = FR_COMMAND (data);
+	FrCommand  *comm = FR_COMMAND (data);
 	FileData   *fdata;
 	char      **fields;
 	char       *filename;
@@ -137,7 +135,6 @@ list__process_line (char     *line,
 	
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 	
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -147,9 +144,10 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_cfile_list (FRCommand *comm)
+fr_command_cfile_list (FrCommand  *comm,
+		       const char *password)
 {
-	FRCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
+	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 
 	if (comm_cfile->compress_prog == FR_COMPRESS_PROGRAM_GZIP) {
 		/* gzip let us known the uncompressed size */
@@ -188,7 +186,6 @@ fr_command_cfile_list (FRCommand *comm)
 		
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 		
 		if (*fdata->name == 0)
 			file_data_free (fdata);
@@ -206,14 +203,14 @@ fr_command_cfile_list (FRCommand *comm)
 
 
 static void
-fr_command_cfile_add (FRCommand     *comm,
+fr_command_cfile_add (FrCommand     *comm,
 		      GList         *file_list,
 		      const char    *base_dir,
 		      gboolean       update,
 		      const char    *password,
 		      FRCompression  compression)
 {
-	FRCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
+	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 	const char     *filename;
 	char           *temp_dir;
 	char           *e_temp_dir;
@@ -236,6 +233,7 @@ fr_command_cfile_add (FRCommand     *comm,
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_set_working_dir (comm->process, base_dir);
 	fr_process_add_arg (comm->process, "-f");
+	fr_process_add_arg (comm->process, "--");
 	fr_process_add_arg (comm->process, filename);
 	fr_process_add_arg (comm->process, temp_file);
 	fr_process_end_command (comm->process);
@@ -249,6 +247,7 @@ fr_command_cfile_add (FRCommand     *comm,
 	case FR_COMPRESS_PROGRAM_GZIP:
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
 		break;
@@ -256,6 +255,7 @@ fr_command_cfile_add (FRCommand     *comm,
 	case FR_COMPRESS_PROGRAM_BZIP:
 		fr_process_begin_command (comm->process, "bzip");
 		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
 		break;
@@ -263,6 +263,7 @@ fr_command_cfile_add (FRCommand     *comm,
 	case FR_COMPRESS_PROGRAM_BZIP2:
 		fr_process_begin_command (comm->process, "bzip2");
 		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
 		break;
@@ -271,6 +272,7 @@ fr_command_cfile_add (FRCommand     *comm,
 		fr_process_begin_command (comm->process, "compress");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
 		break;
@@ -280,6 +282,7 @@ fr_command_cfile_add (FRCommand     *comm,
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "-fU");
 		fr_process_add_arg (comm->process, "--no-stdin");
+		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
 		break;
@@ -290,6 +293,7 @@ fr_command_cfile_add (FRCommand     *comm,
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_set_working_dir (comm->process, e_temp_dir);
 	fr_process_add_arg (comm->process, "-f");
+	fr_process_add_arg (comm->process, "--");
 	fr_process_add_arg (comm->process, "*");
 	fr_process_add_arg (comm->process, comm->e_filename);
 	fr_process_end_command (comm->process);
@@ -299,6 +303,7 @@ fr_command_cfile_add (FRCommand     *comm,
 	fr_process_begin_command (comm->process, "rm");
 	fr_process_set_sticky (comm->process, TRUE);
 	fr_process_add_arg (comm->process, "-rf");
+	fr_process_add_arg (comm->process, "--");
 	fr_process_add_arg (comm->process, e_temp_dir);
 	fr_process_end_command (comm->process);
 
@@ -309,7 +314,7 @@ fr_command_cfile_add (FRCommand     *comm,
 
 
 static void
-fr_command_cfile_delete (FRCommand *comm,
+fr_command_cfile_delete (FrCommand *comm,
 			 GList     *file_list)
 {
 	/* never called */
@@ -317,7 +322,7 @@ fr_command_cfile_delete (FRCommand *comm,
 
 
 static void
-fr_command_cfile_extract (FRCommand  *comm,
+fr_command_cfile_extract (FrCommand  *comm,
 			  GList      *file_list,
 			  const char *dest_dir,
 			  gboolean    overwrite,
@@ -325,13 +330,15 @@ fr_command_cfile_extract (FRCommand  *comm,
 			  gboolean    junk_paths,
 			  const char *password)
 {
-	FRCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
+	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 	char           *temp_dir;
 	char           *e_temp_dir;
 	char           *dest_file;
 	char           *e_dest_file;
 	char           *temp_file;
+	char           *e_temp_file;
 	char           *uncompr_file;
+	char           *e_uncompr_file;
 	char           *compr_file;
 
 	/* create a temp dir. */
@@ -341,15 +348,16 @@ fr_command_cfile_extract (FRCommand  *comm,
 
 	/* copy file to the temp dir, remove the already existing file first */
 
-	temp_file = g_strconcat (e_temp_dir,
+	temp_file = g_strconcat (temp_dir,
 				 "/",
-				 file_name_from_path (comm->e_filename),
+				 file_name_from_path (comm->filename),
 				 NULL);
+	e_temp_file = fr_command_escape (comm, temp_file);
 
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_add_arg (comm->process, "-f");
 	fr_process_add_arg (comm->process, comm->e_filename);
-	fr_process_add_arg (comm->process, temp_file);
+	fr_process_add_arg (comm->process, e_temp_file);
 	fr_process_end_command (comm->process);
 
 	/* uncompress the file */
@@ -363,7 +371,7 @@ fr_command_cfile_extract (FRCommand  *comm,
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
 		fr_process_add_arg (comm->process, "-n");
-		fr_process_add_arg (comm->process, temp_file);
+		fr_process_add_arg (comm->process, e_temp_file);
 		fr_process_end_command (comm->process);
 		break;
 
@@ -371,7 +379,7 @@ fr_command_cfile_extract (FRCommand  *comm,
 		fr_process_begin_command (comm->process, "bzip");
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
-		fr_process_add_arg (comm->process, temp_file);
+		fr_process_add_arg (comm->process, e_temp_file);
 		fr_process_end_command (comm->process);
 		break;
 
@@ -379,14 +387,14 @@ fr_command_cfile_extract (FRCommand  *comm,
 		fr_process_begin_command (comm->process, "bzip2");
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
-		fr_process_add_arg (comm->process, temp_file);
+		fr_process_add_arg (comm->process, e_temp_file);
 		fr_process_end_command (comm->process);
 		break;
 
 	case FR_COMPRESS_PROGRAM_COMPRESS: 
 		fr_process_begin_command (comm->process, "uncompress");
 		fr_process_add_arg (comm->process, "-f");
-		fr_process_add_arg (comm->process, temp_file);
+		fr_process_add_arg (comm->process, e_temp_file);
 		fr_process_end_command (comm->process);
 		break;
 
@@ -396,7 +404,7 @@ fr_command_cfile_extract (FRCommand  *comm,
 		fr_process_add_arg (comm->process, "-d");
 		fr_process_add_arg (comm->process, "-fU");
 		fr_process_add_arg (comm->process, "--no-stdin");
-		fr_process_add_arg (comm->process, temp_file);
+		fr_process_add_arg (comm->process, e_temp_file);
 		fr_process_end_command (comm->process);
 		break;
 	}
@@ -404,10 +412,11 @@ fr_command_cfile_extract (FRCommand  *comm,
 	/* copy uncompress file to the dest dir */
 
 	uncompr_file = remove_extension_from_path (temp_file);
-
+        e_uncompr_file = fr_command_escape (comm, uncompr_file);
+        
 	compr_file = get_uncompressed_name_from_archive (comm, comm->filename);
 	if (compr_file == NULL) 
-		compr_file = remove_extension_from_path (file_name_from_path (comm->e_filename));
+		compr_file = remove_extension_from_path (file_name_from_path (comm->filename));
 	dest_file = g_strconcat (dest_dir,
 				 "/",
 				 compr_file,
@@ -418,7 +427,7 @@ fr_command_cfile_extract (FRCommand  *comm,
 
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_add_arg (comm->process, "-f");
-	fr_process_add_arg (comm->process, uncompr_file);
+	fr_process_add_arg (comm->process, e_uncompr_file);
 	fr_process_add_arg (comm->process, e_dest_file);
 	fr_process_end_command (comm->process);
 
@@ -432,20 +441,22 @@ fr_command_cfile_extract (FRCommand  *comm,
 
 	g_free (e_dest_file);
 	g_free (uncompr_file);
+	g_free (e_uncompr_file);
 	g_free (temp_file);
+	g_free (e_temp_file);
 	g_free (e_temp_dir);
 	g_free (temp_dir);
 }
 
 
 static void 
-fr_command_cfile_class_init (FRCommandCFileClass *class)
+fr_command_cfile_class_init (FrCommandCFileClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+        FrCommandClass *afc;
 
         parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	afc = (FrCommandClass*) class;
 
         gobject_class->finalize = fr_command_cfile_finalize;
 
@@ -457,7 +468,7 @@ fr_command_cfile_class_init (FRCommandCFileClass *class)
 
  
 static void 
-fr_command_cfile_init (FRCommand *comm)
+fr_command_cfile_init (FrCommand *comm)
 {
 	comm->propAddCanUpdate             = FALSE;
 	comm->propAddCanReplace            = FALSE; 
@@ -472,7 +483,7 @@ fr_command_cfile_init (FRCommand *comm)
 static void 
 fr_command_cfile_finalize (GObject *object)
 {
-	FRCommandCFile *comm_tar;
+	FrCommandCFile *comm_tar;
 
         g_return_if_fail (object != NULL);
         g_return_if_fail (FR_IS_COMMAND_CFILE (object));
@@ -492,13 +503,13 @@ fr_command_cfile_get_type ()
 
         if (! type) {
                 GTypeInfo type_info = {
-			sizeof (FRCommandCFileClass),
+			sizeof (FrCommandCFileClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_cfile_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandCFile),
+			sizeof (FrCommandCFile),
 			0,
 			(GInstanceInitFunc) fr_command_cfile_init
 		};
@@ -513,12 +524,12 @@ fr_command_cfile_get_type ()
 }
 
 
-FRCommand *
-fr_command_cfile_new (FRProcess         *process,
+FrCommand *
+fr_command_cfile_new (FrProcess         *process,
 		      const char        *filename,
 		      FRCompressProgram  prog)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if ((prog == FR_COMPRESS_PROGRAM_GZIP) &&
 	    (!is_program_in_path("gzip"))) {
