@@ -26,21 +26,19 @@
 #include <unistd.h>
 
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "file-data.h"
 #include "file-utils.h"
 #include "fr-command.h"
 #include "fr-command-unstuff.h"
 
-static void fr_command_unstuff_class_init  (FRCommandUnstuffClass *class);
-static void fr_command_unstuff_init        (FRCommand         *afile);
+static void fr_command_unstuff_class_init  (FrCommandUnstuffClass *class);
+static void fr_command_unstuff_init        (FrCommand         *afile);
 static void fr_command_unstuff_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 /* recursive rmdir to remove the left-overs from unstuff */
 static void
@@ -103,14 +101,14 @@ unstuff_is_shit_with_filenames (const char *orig)
 
 	return filename;
 }
-	
-	
+
+
 static void
-process_line (char     *line, 
+process_line (char     *line,
 	      gpointer  data)
 {
-	FRCommand        *comm = FR_COMMAND (data);
-	FRCommandUnstuff *unstuff_comm = FR_COMMAND_UNSTUFF (comm);
+	FrCommand        *comm = FR_COMMAND (data);
+	FrCommandUnstuff *unstuff_comm = FR_COMMAND_UNSTUFF (comm);
 	const char       *str_start;
 	char             *filename, *real_filename;
 	int               i;
@@ -182,14 +180,14 @@ process_line (char     *line,
 
 
 static void
-fr_command_unstuff_list (FRCommand  *comm,
+fr_command_unstuff_list (FrCommand  *comm,
 			 const char *password)
 {
 	char *arg, *path;
 	char *filename;
 	char *path_dots;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line,
 				      comm);
 
@@ -215,7 +213,7 @@ fr_command_unstuff_list (FRCommand  *comm,
 
 
 static void
-fr_command_unstuff_extract (FRCommand  *comm,
+fr_command_unstuff_extract (FrCommand  *comm,
 			    GList      *file_list,
 			    const char *dest_dir,
 			    gboolean    overwrite,
@@ -259,36 +257,36 @@ fr_command_unstuff_extract (FRCommand  *comm,
 
 
 static void
-fr_command_unstuff_handle_error (FRCommand   *comm, 
+fr_command_unstuff_handle_error (FrCommand   *comm,
 			     FRProcError *error)
 {
-	if ((error->type == FR_PROC_ERROR_GENERIC) 
+	if ((error->type == FR_PROC_ERROR_COMMAND_ERROR)
 	    && (error->status <= 1))
 		error->type = FR_PROC_ERROR_NONE;
 }
 
 
-static void 
-fr_command_unstuff_class_init (FRCommandUnstuffClass *class)
+static void
+fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 {
-        GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+	FrCommandClass *afc;
 
-        parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	parent_class = g_type_class_peek_parent (class);
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_unstuff_finalize;
 
-        afc->list         = fr_command_unstuff_list;
+	afc->list         = fr_command_unstuff_list;
 	afc->add          = NULL;
 	afc->delete       = NULL;
 	afc->extract      = fr_command_unstuff_extract;
 	afc->handle_error = fr_command_unstuff_handle_error;
 }
 
- 
-static void 
-fr_command_unstuff_init (FRCommand *comm)
+
+static void
+fr_command_unstuff_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_STUFFIT;
 
@@ -303,12 +301,12 @@ fr_command_unstuff_init (FRCommand *comm)
 }
 
 
-static void 
+static void
 fr_command_unstuff_finalize (GObject *object)
 {
-	FRCommandUnstuff *unstuff_comm = FR_COMMAND_UNSTUFF (object);
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (FR_IS_COMMAND_UNSTUFF (object));
+	FrCommandUnstuff *unstuff_comm = FR_COMMAND_UNSTUFF (object);
+	g_return_if_fail (object != NULL);
+	g_return_if_fail (FR_IS_COMMAND_UNSTUFF (object));
 
 	if (unstuff_comm->target_dir != NULL) {
 		recursive_rmdir (unstuff_comm->target_dir);
@@ -316,7 +314,7 @@ fr_command_unstuff_finalize (GObject *object)
 	}
 
 	/* Chain up */
-        if (G_OBJECT_CLASS (parent_class)->finalize)
+	if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -324,17 +322,17 @@ fr_command_unstuff_finalize (GObject *object)
 GType
 fr_command_unstuff_get_type ()
 {
-        static GType type = 0;
+	static GType type = 0;
 
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (FRCommandUnstuffClass),
+	if (! type) {
+		GTypeInfo type_info = {
+			sizeof (FrCommandUnstuffClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_unstuff_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandUnstuff),
+			sizeof (FrCommandUnstuff),
 			0,
 			(GInstanceInitFunc) fr_command_unstuff_init
 		};
@@ -343,17 +341,17 @@ fr_command_unstuff_get_type ()
 					       "FRCommandUnstuff",
 					       &type_info,
 					       0);
-        }
+	}
 
-        return type;
+	return type;
 }
 
 
-FRCommand *
-fr_command_unstuff_new (FRProcess  *process,
+FrCommand *
+fr_command_unstuff_new (FrProcess  *process,
 		    const char *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path("unstuff")) {
 		return NULL;
