@@ -32,13 +32,13 @@
 #include "fr-command.h"
 #include "fr-command-zoo.h"
 
-static void fr_command_zoo_class_init  (FRCommandZooClass *class);
-static void fr_command_zoo_init        (FRCommand         *afile);
+static void fr_command_zoo_class_init  (FrCommandZooClass *class);
+static void fr_command_zoo_init        (FrCommand         *afile);
 static void fr_command_zoo_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 /* -- list -- */
@@ -175,7 +175,7 @@ process_zoo_line (char     *line,
 		  gpointer  data)
 {
 	FileData    *fdata;
-	FRCommand   *zoo_comm = FR_COMMAND (data);
+	FrCommand   *zoo_comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 
@@ -218,7 +218,7 @@ process_zoo_line (char     *line,
 
 
 static void
-fr_command_zoo_list (FRCommand  *zoo_comm,
+fr_command_zoo_list (FrCommand  *zoo_comm,
 		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (zoo_comm)->process,
@@ -234,7 +234,7 @@ fr_command_zoo_list (FRCommand  *zoo_comm,
 
 
 static void
-fr_command_zoo_add (FRCommand     *comm,
+fr_command_zoo_add (FrCommand     *comm,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
@@ -263,7 +263,7 @@ fr_command_zoo_add (FRCommand     *comm,
 
 
 static void
-fr_command_zoo_delete (FRCommand *comm,
+fr_command_zoo_delete (FrCommand *comm,
 		       GList     *file_list)
 {
 	GList        *scan;
@@ -281,7 +281,7 @@ fr_command_zoo_delete (FRCommand *comm,
 
 
 static void
-fr_command_zoo_extract (FRCommand  *comm,
+fr_command_zoo_extract (FrCommand  *comm,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
@@ -311,7 +311,7 @@ fr_command_zoo_extract (FRCommand  *comm,
 
 
 static void
-fr_command_zoo_test (FRCommand   *comm,
+fr_command_zoo_test (FrCommand   *comm,
 		     const char  *password)
 {
 	fr_process_begin_command (comm->process, "zoo");
@@ -322,13 +322,13 @@ fr_command_zoo_test (FRCommand   *comm,
 
 
 static void 
-fr_command_zoo_class_init (FRCommandZooClass *class)
+fr_command_zoo_class_init (FrCommandZooClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+        FrCommandClass *afc;
 
         parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_zoo_finalize;
 
@@ -341,7 +341,7 @@ fr_command_zoo_class_init (FRCommandZooClass *class)
 
  
 static void 
-fr_command_zoo_init (FRCommand *comm)
+fr_command_zoo_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_ZOO;
 
@@ -374,13 +374,13 @@ fr_command_zoo_get_type ()
 
         if (! type) {
                 GTypeInfo type_info = {
-			sizeof (FRCommandZooClass),
+			sizeof (FrCommandZooClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_zoo_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandZoo),
+			sizeof (FrCommandZoo),
 			0,
 			(GInstanceInitFunc) fr_command_zoo_init
 		};
@@ -394,11 +394,11 @@ fr_command_zoo_get_type ()
         return type;
 }
 
-FRCommand *
-fr_command_zoo_new (FRProcess         *process,
+FrCommand *
+fr_command_zoo_new (FrProcess         *process,
 		    const char        *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path("zoo")) {
 		return NULL;
